@@ -299,7 +299,8 @@ class Scanner(object):
 
         # A simple key is required only if it is the first token in the current
         # line. Therefore it is always allowed.
-        assert self.allow_simple_key or not required
+        # http://marc.info/?l=oss-security&m=141720508007010&w=2
+        #assert self.allow_simple_key or not required
 
         # The next token might be a simple key. Let's save it's number and
         # position.
@@ -374,7 +375,8 @@ class Scanner(object):
         # Set the current intendation to -1.
         self.unwind_indent(-1)
 
-        # Reset everything (not really needed).
+        # Reset simple keys.
+        self.remove_possible_simple_key()
         self.allow_simple_key = False
         self.possible_simple_keys = {}
 
